@@ -15,11 +15,12 @@
 from jinja2 import Environment, PackageLoader, select_autoescape, Template
 
 env = Environment(
-    loader=PackageLoader('flaskstarter', 'templates'),
-    autoescape=select_autoescape('pyt', 'htmlt', 'tomlt')
+    loader=PackageLoader("flaskstarter", "templates"),
+    autoescape=select_autoescape("pyt", "htmlt", "tomlt"),
 )
 
-def get_template(name : str) -> Template:
+
+def get_template(name: str) -> Template:
     """Retrieves and return the specified template.
 
     Args:
